@@ -74,7 +74,7 @@ def __getattr__(identifier: str) -> object:
     return globals()[identifier.__path__]
 
 
-def api_converter(api):
+def api_converter(api: str):
     if api[-2:] in ['()', '（）']:
         api = api[:-2]
     for keys, values in apis.items():
@@ -82,6 +82,14 @@ def api_converter(api):
             return values[0], values[1]
     return False, '该API并不存在'
 
+
+def api_converter_re(method: str, path: str):
+    for keys, values in apis.items():
+        if [method, path] == values:
+            return keys[1]
+    return None
+
+
 class ReplyModel:
     def __init__(self, type_: object or dict = object):
         if stack()[1].filename.split('\\')[-1] != 'qg_bot.py':
@@ -757,6 +765,7 @@ class ReplyModel:
 
     def get_guild_permissions(self):
         class Api:
+            api: str
             path: str
             method: str
             desc: str
